==> edc_screening-0.3.45-py3-none-any.whl: edc_screening/form_validator_mixins.py <==
from __future__ import annotations

from typing import TYPE_CHECKING, Type

from django.apps import apps as django_apps
from django.core.exceptions import ObjectDoesNotExist
from edc_consent.exceptions import ConsentDefinitionDoesNotExist
from edc_consent.site_consents import site_consents
from edc_form_validators import INVALID_ERROR
from edc_sites.site import sites

from .utils import get_subject_screening_model

if TYPE_CHECKING:
    from edc_consent.consent_definition import ConsentDefinition

    from .model_mixins import ScreeningModelMixin


class SubjectScreeningFormValidatorMixin:
    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self._subject_screening = None

    @property
    def screening_identifier(self):
        return self.cleaned_data.get("screening_identifier")

    @property
    def report_datetime(self):
        return self.cleaned_data.get("report_datetime")

    @property
    def subject_screening_model(self) -> str:
        return get_subject_screening_model()

    @property
    def subject_screening_model_cls(self) -> Type[ScreeningModelMixin]:
        return django_apps.get_model(self.subject_screening_model)

    @property
    def subject_screening(self) -> ScreeningModelMixin:
        if not self._subject_screening:
            try:
                self._subject_screening = self.subject_screening_model_cls.objects.get(
                    screening_identifier=self.screening_identifier
                )
            except ObjectDoesNotExist:
                self.raise_validation_error(
                    'Complete the "Subject Screening" form before proceeding.',
                    code="missing_subject_screening",
                )
        return self._subject_screening

    def get_consent_definition_or_raise(self) -> ConsentDefinition:
        try:
            consent_definition = site_consents.get_consent_definition(
                report_datetime=self.report_datetime,
                site=sites.get(self.instance.site.id),
            )
        except ConsentDefinitionDoesNotExist as e:
            self.raise_validation_error(str(e), INVALID_ERROR)
        return consent_definition

==> edc_screening-0.3.51-py3-none-any.whl: edc_screening/form_validator_mixins.py <==
from __future__ import annotations

from typing import TYPE_CHECKING, Type

from django.apps import apps as django_apps
from django.core.exceptions import ObjectDoesNotExist
from edc_consent import site_consents

from .utils import get_subject_screening_model

if TYPE_CHECKING:
    from edc_consent.consent_definition import ConsentDefinition

    from .model_mixins import ScreeningModelMixin


class SubjectScreeningFormValidatorMixin:
    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self._subject_screening = None

    @property
    def screening_identifier(self):
        return self.cleaned_data.get("screening_identifier")

    @property
    def report_datetime(self):
        return self.cleaned_data.get("report_datetime")

    @property
    def subject_screening_model(self) -> str:
        return get_subject_screening_model()

    @property
    def subject_screening_model_cls(self) -> Type[ScreeningModelMixin]:
        return django_apps.get_model(self.subject_screening_model)

    @property
    def subject_screening(self) -> ScreeningModelMixin:
        if not self._subject_screening:
            try:
                self._subject_screening = self.subject_screening_model_cls.objects.get(
                    screening_identifier=self.screening_identifier
                )
            except ObjectDoesNotExist:
                self.raise_validation_error(
                    'Complete the "Subject Screening" form before proceeding.',
                    code="missing_subject_screening",
                )
        return self._subject_screening

    def get_consent_definition_or_raise(self) -> ConsentDefinition:
        """Is there a single consent definition registered"""
        return site_consents.get_consent_definition(
            screening_model=self.instance._meta.label_lower,
            report_datetime=self.report_datetime,
        )
